export default {
    "message": "Cannot use keyword 'await' outside an async function",
    "column": 12,
    "index": 11,
    "lineNumber": 1
};
